tests package — imagedata 1.3.6 documentation

# tests package

## Submodules

## tests.compare_headers module

`tests.compare_headers.` `compare_geometry_headers`(self, self, newhdr)

`tests.compare_headers.` `compare_headers`(self, self, newhdr, uid=True)

`tests.compare_headers.` `compare_optional`(self, a, b, attr)

`tests.compare_headers.` `compare_template_headers`(self, self, newhdr, uid=True)

## tests.context module

## tests.test_archive_file module

Test file archive

class `tests.test_archive_file.` `TestArchiveFile`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_mimetype`()
  `test_new_archive`()
  `test_unknown_mimetype`()
  `test_unknown_url`()

## tests.test_archive_zip module

Test zip archive

class `tests.test_archive_zip.` `TestArchiveZip`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_mimetype`()
  `test_new_archive`()
  `test_unknown_mimetype`()
  `test_unknown_url`()

## tests.test_axis module

class `tests.test_axis.` `TestAxis`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_uniform_axis`()
  `test_uniform_length_axis`()
  `test_uniform_length_axis_step2`()
  `test_variable_axis`()
  `test_variable_axis2`()
  `test_variable_axis_rgb`()

## tests.test_formats_dicom module

## tests.test_formats_dicom_color module

## tests.test_formats_dicom_template module

## tests.test_formats_dicom_zip module

## tests.test_formats_itk module

## tests.test_formats_itk_template module

## tests.test_formats_itk_zip module

## tests.test_formats_mat module

## tests.test_formats_mat_zip module

## tests.test_formats_nifti module

## tests.test_formats_nifti_zip module

## tests.test_formats_ps module

## tests.test_series module

## tests.test_transport_dicomtransport module

## tests.test_transport_filetransport module

Test file archive

class `tests.test_transport_filetransport.` `TestFiletransport`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_isfile`()
  `test_open_file`()
  `test_open_new`()
  `test_open_nonexist`()
  `test_open_nonexist_dir`()
  `test_readfile`()
  `test_walk`()
  `test_write_then_read`()

## tests.test_version module

class `tests.test_version.` `TestVersion`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_version`()

## Module contents